<template>
    <el-cascader
        v-model="value"
        :options="options"
        :show-all-levels="false"
        clearable
        :props="{
            expandTrigger: 'hover',
            checkStrictly: true,
            value: 'id',
            label: 'name',
            children: 'chirldren',
        }"
        style="width: 190px; margin-right: 10px"
        ref="cascader"
        @change="handleCascaderChange"
    ></el-cascader>
</template>

<script>
import orgData from './orgData.json'
export default {
    props: {
        placeholder: {
            type: String,
            default: '请选择',
        },
        companyId: {
            type: Array,
            default: () => ['1419863231459102720'],
        },
    },
    data() {
        return {
            options: [], // orgData.list,
            value: this.companyId,
            companyIds: [],
            roadSegmentId: '',
        }
    },
    watch: {
        companyId(newVal) {
            this.value = newVal
        },
    },
    created() {
        this.loadData()
    },
    methods: {
        loadData() {
            this.$http.get('${yhxt}/road/roadmanage/v1/roadTree').then((res) => {
                let data = (res && res.status == 200 && res.data) || []
                this.deepSetChildren(data) // 设置路段的children为null
                this.options = [
                    {
                        isDelete: '0',
                        id: '1419863231459102720',
                        name: '全国',
                        parentId: '0',
                        code: '10',
                        grade: '1',
                        orgKind: 'ogn',
                        demId: '1258608622670319616',
                        orderNo: 145,
                        isMaster: 0,
                        path: '1258608622670319616.1419863231459102720.',
                        pathName: '/中铁建昆仑投资集团',
                        limitNum: 0,
                        exceedLimitNum: 0,
                        disabled: false,
                        chirldren: data,
                    },
                ]
            })
        },
        deepSetChildren(data) {
            data.forEach((i) => {
                let child = i.chirldren
                if (child && child.length !== 0) {
                    return this.deepSetChildren(child)
                } else {
                    i.chirldren = null
                }
            })
            return data
        },
        handleCascaderChange(val) {
            let companyIds = []
            this.roadSegmentId = ''
            if (val && val.length == 1) {
                companyIds = [
                    '1419863231459102720',
                    '1497492989159804928',
                    '1430710034819584000',
                    '1497492555523297280',
                    '1497492614272913408',
                    '1497492713090715648',
                    '1497492783722795008',
                    '1497492820871745536',
                    '1497492898147602432',
                    '1430734631036129280',
                    '1497493076619431936',
                    '1497493109293060096',
                    '1497493158022483968',
                    '1494140182780317696',
                    '1497493254181097472',
                    '1497493287089606656',
                    '1497493237982695424',
                    '1419863231459102720',
                ]
            }
            let selectedList = this.$refs.cascader.getCheckedNodes()
            companyIds = this.deepClone(selectedList)
            companyIds = [...val, ...companyIds]
            selectedList.forEach((i) => {
                if (!i.hasChildren && i.data.roadSegmentId) {
                    this.roadSegmentId = i.data.id
                }
            })

            this.companyIds = companyIds
            if (companyIds.length == 0) {
                this.companyIds = ''
            }
            if (this.roadSegmentId) {
                this.companyIds = ''
            }

            this.$emit('update:companyIds', this.companyIds)
            this.$emit('update:companyId', this.value)
            this.$emit('update:roadSegmentId', this.roadSegmentId)
        },
        deepClone(source) {
            let result = []
            if (source && source.length === 0) return []
            source.forEach((i) => {
                if (i.children.length !== 0) {
                    result = [...result, ...this.deepClone(i.children)]
                } else {
                    result.push(i.data.id)
                }
            })
            return result
        },
    },
}
</script>

<style lang="scss">
.el-cascader-node__label {
    font-size: 16px;
}
.el-radio.is-checked + .el-cascader-node__label {
    color: #409eff;
}
.el-scrollbar__view .el-cascader-node > .el-radio {
    width: 100%;
    height: 100%;
    z-index: 10;
    position: absolute;
    top: 10px;
    right: -8px;
}
.el-scrollbar__view .el-cascader-node:not(.is-disabled):hover,
.el-select-dropdown__item:hover {
    background: #fff !important;
}
.el-select-dropdown__item:hover span {
    color: #0283fc;
}
.el-scrollbar__view .el-cascader-node:not(.is-disabled):hover .el-cascader-node__label,
.el-scrollbar__view .el-cascader-node:not(.is-disabled):hover .el-icon-arrow-right {
    color: #0283fc !important;
    font-weight: bold;
}
.el-cascader-node.is-selectable.in-active-path {
    color: #0283fc !important;
}
.el-popper {
    background-color: rgba($color: #112b44, $alpha: 0.9) !important;
}
.el-cascader-menu {
    //   border: 1px solid #fff;
    &:nth-child(n + 1) {
        border-right: 1px solid #fff;
    }
    &:nth-child(n + 2) {
        border-left: none;
    }
    &:last-child {
        border-right: none;
    }
}
// .el-scrollbar {
//   background-color: transparent;
// }
.el-cascader-panel {
    border-radius: 5px;
    border: 1px solid #fff;
}
.el-select-dropdown .el-scrollbar {
    border: 1px solid #0283fc;
    //   padding-left: 10px;
    border-radius: 5px;
}
.in-active-path span {
    color: #0283fc;
}
.el-month-table td .cell {
    color: #fff;
    font-size: 14px;
    font-weight: bold;
}
.el-month-table td.current:not(.disabled) .cell {
    color: #d7ef05;
}
.el-date-picker__header--bordered {
    border-bottom-color: #0283da;
}

.el-cascader-node__label {
    font-size: 16px;
}
.el-radio.is-checked + .el-cascader-node__label {
    color: #409eff;
}
.el-scrollbar__view .el-cascader-node > .el-radio {
    width: 100%;
    height: 100%;
    z-index: 10;
    position: absolute;
    top: 10px;
    right: -8px;
}
.el-picker-panel__body {
    border-radius: 5px;
    background-color: rgba($color: #2c6d89, $alpha: 0.8);
}
// .el-cascader-panel .el-radio__input {
//   visibility: hidden;
// }
// .el-cascader-panel .el-cascader-node__postfix {
//   top: 10px;
// }
</style>
